@@ -51,8 +51,10 @@ impl<'a> Iterator for Iter<'a> {
                     },
                 };
                 self.cursor = match dir.parent() {
-                    Some(parent) => (parent != self.boundary).then(||parent),
-                    None => unreachable!("directory {:?} ran out of parents, this really shouldn't happen before hitting the boundary {:?}"),
+                    Some(parent) => (parent != self.boundary).then(|| parent),
+                    None => {
+                        unreachable!("directory {:?} ran out of parents, this really shouldn't happen before hitting the boundary {:?}")
+                    }
                 };
                 next
             }
